tools

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2025 License: EUPL-1.2 Imports: 8 Imported by: 0

Documentation

Overview

Package tools provides a collection of functions to build needed tools.

Index

Constants

This section is empty.

Variables

var (
	EnvDirectProxy = []string{"GOPROXY=direct"}
	EnvGoVCS       = []string{"GOVCS=zettelstore.de:fossil,t73f.de:fossil"}
)

Some constants to make Go work with fossil.

var Verbose bool

Verbose signals a verbose tool execution.

Functions

func Check

func Check(forRelease bool) error

Check the source with some linters.

func CheckGoTest

func CheckGoTest(pkg string, testParams ...string) error

CheckGoTest runs all internal unti tests.

func ExecuteCommand

func ExecuteCommand(env []string, name string, arg ...string) (string, error)

ExecuteCommand executes a specific command.

func ExecuteFilter

func ExecuteFilter(data []byte, env []string, name string, arg ...string) (string, string, error)

ExecuteFilter executes an external program to be used as a filter.

func LogCommand

func LogCommand(exec string, env []string, name string, arg []string)

LogCommand logs the execution of a command.

func PrepareCommand

func PrepareCommand(env []string, name string, arg []string, in io.Reader, stdout, stderr io.Writer) *exec.Cmd

PrepareCommand creates a commands to be executed.

Types

This section is empty.

Directories

Path Synopsis
Package main provides a command to build and run the software.
Package main provides a command to build and run the software.
Package main provides a command to execute unit tests.
Package main provides a command to execute unit tests.
Package main provides a command to clean / remove development artifacts.
Package main provides a command to clean / remove development artifacts.
Package main provides a command to install development tools.
Package main provides a command to install development tools.
Package main provides a tool to check the validity of HTML zettel documents.
Package main provides a tool to check the validity of HTML zettel documents.
Package main provides a command to test the API
Package main provides a command to test the API

Jump to