Documentation
¶
Overview ¶
Package tools provides a collection of functions to build needed tools.
Index ¶
- Variables
- func Check(forRelease bool) error
- func CheckGoTest(pkg string, testParams ...string) error
- func ExecuteCommand(env []string, name string, arg ...string) (string, error)
- func ExecuteFilter(data []byte, env []string, name string, arg ...string) (string, string, error)
- func LogCommand(exec string, env []string, name string, arg []string)
- func PrepareCommand(env []string, name string, arg []string, in io.Reader, ...) *exec.Cmd
Constants ¶
This section is empty.
Variables ¶
var ( EnvDirectProxy = []string{"GOPROXY=direct"} EnvGoVCS = []string{"GOVCS=zettelstore.de:fossil,t73f.de:fossil"} )
Some constants to make Go work with fossil.
var Verbose bool
Verbose signals a verbose tool execution.
Functions ¶
func CheckGoTest ¶
CheckGoTest runs all internal unti tests.
func ExecuteCommand ¶
ExecuteCommand executes a specific command.
func ExecuteFilter ¶
ExecuteFilter executes an external program to be used as a filter.
func LogCommand ¶
LogCommand logs the execution of a command.
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package main provides a command to build and run the software.
|
Package main provides a command to build and run the software. |
|
Package main provides a command to execute unit tests.
|
Package main provides a command to execute unit tests. |
|
Package main provides a command to clean / remove development artifacts.
|
Package main provides a command to clean / remove development artifacts. |
|
Package main provides a command to install development tools.
|
Package main provides a command to install development tools. |
|
Package main provides a tool to check the validity of HTML zettel documents.
|
Package main provides a tool to check the validity of HTML zettel documents. |
|
Package main provides a command to test the API
|
Package main provides a command to test the API |
Click to show internal directories.
Click to hide internal directories.